KashiColors class

Constructors

KashiColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

white05 Color
getter/setter pair
whiteFA Color
getter/setter pair

Constants

bg1 → const Color
bg2 → const Color
borderColor → const Color
errorColor → const Color
green2 → const Color
grey1 → const Color
grey01 → const Color
grey2 → const Color
grey3 → const Color
grey4 → const Color
grey5 → const Color
grey6 → const Color
grey7 → const Color
liveMatchGradient → const RadialGradient
orange1 → const Color
orange2 → const Color
orange3 → const Color
orange4 → const Color
playerAttack → const LinearGradient
playerDefault → const LinearGradient
playerForward → const LinearGradient
playerGoalKeeper → const LinearGradient
playerGradient → const LinearGradient
pollsGreen → const List<Color>
pollsGrey → const List<Color>
pollsOrange → const List<Color>
polls gradient
primary2 → const Color
primary02 → const Color
primary4 → const Color
primary04 → const Color
primary5 → const Color
primary6 → const Color
primary06 → const Color
primary07 → const Color
primary08 → const Color
primaryColor → const MaterialColor
ratingOrange → const List<Color>
red1 → const Color
red2 → const Color
red3 → const Color
red4 → const Color
secondary1 → const Color
secondary2 → const Color
secondary02 → const Color
secondary3 → const Color
secondary03 → const Color
secondary4 → const Color
secondary5 → const Color
secondary05 → const Color
secondary06 → const Color
secondary07 → const Color
secondary08 → const Color
secondary09 → const Color
secondary10 → const Color
secondary11 → const Color
secondary12 → const Color
shadowColor → const Color
yellow01 → const Color
yellow03 → const Color