KashiTheme class

Constructors

KashiTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bodyMedium TextStyle
no setter
bodySemiBold TextStyle
no setter
h1Bold TextStyle
no setter
h1Regular TextStyle
no setter
h1SemiBold TextStyle
no setter
h2Bold TextStyle
no setter
h2Regular TextStyle
no setter
h2SemiBold TextStyle
no setter
h3Bold TextStyle
no setter
h3Regular TextStyle
no setter
h3SemiBold TextStyle
no setter
sh1Bold TextStyle
no setter
sh1Regular TextStyle
no setter
sh1SemiBold TextStyle
no setter
sh2Bold TextStyle
no setter
sh2Regular TextStyle
no setter
sh2SemiBold TextStyle
no setter
smallTextMedium TextStyle
no setter
smallTextSemiBold TextStyle
no setter
smallTextSmall TextStyle
no setter
tinyTextMedium TextStyle
no setter
tinyTextSemiBold TextStyle
no setter
tinyTextSmall TextStyle
no setter

Static Methods

buildTheme() ThemeData