Buttons class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
outline({required String text, required VoidCallback? onPressed, bool loading = false, ButtonSize size = ButtonSize.md, Widget? prefixIcon, Widget? suffixIcon, Color? backgroundColor, Color? textColor, MaterialTapTargetSize? tapTargetSize, bool stretch = true, Color? boarderColor, EdgeInsetsGeometry margin = EdgeInsets.zero, EdgeInsetsGeometry? padding})
→ Widget
-
-
primary({required String text, required VoidCallback? onPressed, bool loading = false, ButtonSize size = ButtonSize.md, Widget? prefixIcon, Widget? suffixIcon, Color? backgroundColor, Color? textColor, bool? showShadow, MaterialTapTargetSize? tapTargetSize, bool stretch = true, Color? boarderColor, EdgeInsetsGeometry margin = EdgeInsets.zero, EdgeInsetsGeometry? padding})
→ Widget
-
-
text({required String text, required VoidCallback? onPressed, bool loading = false, ButtonSize buttonSize = ButtonSize.md, Widget? suffixIcon, TextStyle? textStyle, Color? textColor = KashiColors.primaryColor, EdgeInsetsGeometry margin = EdgeInsets.zero, Size size = const Size(0.0, 0.0)})
→ Widget
-