ButtonSize enum
Values
- sm → const ButtonSize
-
const ButtonSize(titlePadding: EdgeInsets.symmetric(horizontal: 14, vertical: 8), fontSize: 14, fontWeight: FontWeight.w600) - md → const ButtonSize
-
const ButtonSize(titlePadding: EdgeInsets.symmetric(horizontal: 16, vertical: 10), fontSize: 14, fontWeight: FontWeight.w600) - lg → const ButtonSize
-
const ButtonSize(titlePadding: EdgeInsets.symmetric(horizontal: 18, vertical: 10), fontSize: 16, fontWeight: FontWeight.w600) - xl → const ButtonSize
-
const ButtonSize(titlePadding: EdgeInsets.symmetric(horizontal: 46, vertical: 14), fontSize: 16, fontWeight: FontWeight.w600) - xxl → const ButtonSize
-
const ButtonSize(titlePadding: EdgeInsets.symmetric(horizontal: 28, vertical: 16), fontSize: 18, fontWeight: FontWeight.w600)
Properties
- fontSize → double
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titlePadding → EdgeInsetsGeometry
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ButtonSize> - A constant List of the values in this enum, in order of their declaration.